@@ -3,7 +3,7 @@
  *  Implementation of GiNaC's ABC. */
 
 /*
- *  GiNaC Copyright (C) 1999-2004 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2005 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include <iostream>
@@ -617,9 +617,11 @@ ex basic::subs_one_level(const exmap & m, unsigned options) const
 	exmap::const_iterator it;
 
 	if (options & subs_options::no_pattern) {
-		it = m.find(*this);
+		ex thisex = *this;
+		it = m.find(thisex);
 		if (it != m.end())
 			return it->second;
+		return thisex;
 	} else {
 		for (it = m.begin(); it != m.end(); ++it) {
 			lst repl_lst;
