@@ -283,7 +283,7 @@ ex expairseq::op(size_t i) const
 ex expairseq::map(map_function &f) const
 {
 	std::auto_ptr<epvector> v(new epvector);
-	v->reserve(seq.size());
+	v->reserve(seq.size()+1);
 
 	epvector::const_iterator cit = seq.begin(), last = seq.end();
 	while (cit != last) {
@@ -293,8 +293,15 @@ ex expairseq::map(map_function &f) const
 
 	if (overall_coeff.is_equal(default_overall_coeff()))
 		return thisexpairseq(v, default_overall_coeff());
-	else
-		return thisexpairseq(v, f(overall_coeff));
+	else {
+      ex newcoeff = f(overall_coeff);
+      if(is_a<numeric>(newcoeff))
+         return thisexpairseq(v, newcoeff);
+      else {
+         v->push_back(split_ex_to_pair(newcoeff));
+         return thisexpairseq(v, default_overall_coeff());
+      }
+   }
 }
 
 /** Perform coefficient-wise automatic term rewriting rules in this class. */
@@ -382,10 +389,20 @@ bool expairseq::match(const ex & pattern, lst & repl_lst) const
 				continue;
 			exvector::iterator it = ops.begin(), itend = ops.end();
 			while (it != itend) {
+				lst::const_iterator last_el = repl_lst.end();
+				--last_el;
 				if (it->match(p, repl_lst)) {
 					ops.erase(it);
 					goto found;
 				}
+				while(true) {
+					lst::const_iterator next_el = last_el;
+					++next_el;
+					if(next_el == repl_lst.end())
+						break;
+					else
+						repl_lst.remove_last();
+				}
 				++it;
 			}
 			return false; // no match found
