@@ -3,7 +3,7 @@
  *  Implementation of GiNaC's exprseq. */
 
 /*
- *  GiNaC Copyright (C) 1999-2004 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2005 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "exprseq.h"
@@ -29,7 +29,7 @@ template <> GINAC_IMPLEMENT_REGISTERED_CLASS_OPT(exprseq, basic,
   print_func<print_tree>(&exprseq::do_print_tree))
 
 /** Specialization of container::info() for exprseq. */
-bool exprseq::info(unsigned inf) const
+template <> bool exprseq::info(unsigned inf) const
 {
 	if (inf == info_flags::exprseq)
 		return true;
