@@ -214,7 +214,7 @@ bool fderivative::match_same_type(const basic & other) const
 	GINAC_ASSERT(is_a<fderivative>(other));
 	const fderivative & o = static_cast<const fderivative &>(other);
 
-	return parameter_set == o.parameter_set;
+	return parameter_set == o.parameter_set && inherited::match_same_type(other);
 }
 
 } // namespace GiNaC
